aboutsummaryrefslogtreecommitdiff
path: root/run-tests-on-android.sh
diff options
context:
space:
mode:
authorElliott Hughes <enh@google.com>2020-01-29 13:36:40 -0800
committerElliott Hughes <enh@google.com>2020-01-29 13:36:40 -0800
commit38d7f3f384899b497a99e5d14760b064f9704a47 (patch)
tree028bf16b6071a5b5db2528316fe196fa1505aa50 /run-tests-on-android.sh
parent6e2accaa6b1a3a91d9c99897ec8d7fa53c7f832f (diff)
downloadtoybox-38d7f3f384899b497a99e5d14760b064f9704a47.tar.gz
Ignore lsattr failures for now too.
The lsattr tests currently pass on blueline but fail on cuttlefish. Too... many... file systems... Bug: http://b/147769529 Test: treehugger Change-Id: I1de08609df55887d5d25bddeae2772fb5b39a649
Diffstat (limited to 'run-tests-on-android.sh')
-rwxr-xr-xrun-tests-on-android.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/run-tests-on-android.sh b/run-tests-on-android.sh
index 0fedce48..40d8eb4c 100755
--- a/run-tests-on-android.sh
+++ b/run-tests-on-android.sh
@@ -62,8 +62,8 @@ test_toy() {
elif [ "$non_toy" = "true" ]; then
non_toy_failures="$non_toy_failures $toy"
else
- # The chattr tests are currently broken. Working on it...
- if [ "$toy" = "chattr" ]; then
+ # The chattr/lsattr tests are currently broken. Working on it...
+ if [ "$toy" = "chattr" || "$toy" = "lsattr" ]; then
non_toy_failures="$non_toy_failures $toy"
else
failures="$failures $toy"